==> jc-1.4.0.tar.gz: java/util/Hashtable__24Enumerator.h <==
// final class java.util.Hashtable$Enumerator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ad1c18e8693472eb java_util_Hashtable__24Enumerator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_Hashtable__24Enumerator_H_
#define _JC_java_util_Hashtable__24Enumerator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Hashtable$object;
struct _jc_java_util_Hashtable__24HashEntry$object;

// Typedefs
typedef struct _jc_java_util_Hashtable__24Enumerator$sub_refs	_jc_java_util_Hashtable__24Enumerator$sub_refs;
typedef struct _jc_java_util_Hashtable__24Enumerator$sub_nonrefs	_jc_java_util_Hashtable__24Enumerator$sub_nonrefs;
typedef struct _jc_java_util_Hashtable__24Enumerator$refs	_jc_java_util_Hashtable__24Enumerator$refs;
typedef struct _jc_java_util_Hashtable__24Enumerator$nonrefs	_jc_java_util_Hashtable__24Enumerator$nonrefs;
typedef struct _jc_java_util_Hashtable__24Enumerator$object	_jc_java_util_Hashtable__24Enumerator$object;

typedef const struct _jc_java_util_Hashtable__24Enumerator$vmethods	_jc_java_util_Hashtable__24Enumerator$vmethods;
typedef const struct _jc_java_util_Hashtable__24Enumerator$vtable	_jc_java_util_Hashtable__24Enumerator$vtable;
typedef const struct _jc_java_util_Hashtable__24Enumerator$vtype	_jc_java_util_Hashtable__24Enumerator$vtype;

// Constructors
extern void _jc_java_util_Hashtable__24Enumerator$method$_init$cea83e7eef93edc7(_jc_env *, struct _jc_java_util_Hashtable__24Enumerator$object *, struct _jc_java_util_Hashtable$object *, jint);

// Virtual methods
extern jboolean _jc_java_util_Hashtable__24Enumerator$method$hasMoreElements$95fbe58f36adadb0(_jc_env *, struct _jc_java_util_Hashtable__24Enumerator$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_Hashtable__24Enumerator$method$nextElement$9b7c3789fa3ba818(_jc_env *, struct _jc_java_util_Hashtable__24Enumerator$object *);
extern void _jc_java_util_Hashtable__24Enumerator$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_util_Hashtable__24Enumerator$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_Hashtable__24Enumerator$method_info$hasMoreElements$95fbe58f36adadb0;
extern _jc_method _jc_java_util_Hashtable__24Enumerator$method_info$nextElement$9b7c3789fa3ba818;
extern _jc_method _jc_java_util_Hashtable__24Enumerator$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_util_Hashtable__24Enumerator$vmethods {
	jboolean	(*hasMoreElements$95fbe58f36adadb0)(_jc_env *, struct _jc_java_util_Hashtable__24Enumerator$object *);
	struct _jc_java_lang_Object$object	*(*nextElement$9b7c3789fa3ba818)(_jc_env *, struct _jc_java_util_Hashtable__24Enumerator$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_util_Hashtable__24Enumerator$object *);
};

// Vtable
struct _jc_java_util_Hashtable__24Enumerator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Hashtable__24Enumerator$vmethods	java_util_Hashtable__24Enumerator;
};

// Vtype
struct _jc_java_util_Hashtable__24Enumerator$vtype {
	_jc_type			type;
	_jc_java_util_Hashtable__24Enumerator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Hashtable__24Enumerator$sub_refs {
	struct _jc_java_util_Hashtable__24HashEntry$object	*next;
	struct _jc_java_util_Hashtable$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_Hashtable__24Enumerator$refs {
    _jc_java_util_Hashtable__24Enumerator$sub_refs	java_util_Hashtable__24Enumerator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Hashtable__24Enumerator$sub_nonrefs {
	jint	type;
	jint	count;
	jint	idx;
};

// Non-reference instance fields (object)
struct _jc_java_util_Hashtable__24Enumerator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Hashtable__24Enumerator$sub_nonrefs	java_util_Hashtable__24Enumerator;
};

// Object instance structure
struct _jc_java_util_Hashtable__24Enumerator$object {
	_jc_java_util_Hashtable__24Enumerator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Hashtable__24Enumerator$vtype	*vtype;
	_jc_java_util_Hashtable__24Enumerator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Hashtable__24Enumerator$vtype _jc_java_util_Hashtable__24Enumerator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Hashtable__24Enumerator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Hashtable__24Enumerator$class_object;

#endif	/* _JC_java_util_Hashtable__24Enumerator_H_ */

==> jc-1.4.6.tar.gz: java/util/Hashtable__24Enumerator.h <==
// final class java.util.Hashtable$Enumerator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ad1c18e8693472eb java_util_Hashtable__24Enumerator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_Hashtable__24Enumerator_H_
#define _JC_java_util_Hashtable__24Enumerator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Hashtable$object;
struct _jc_java_util_Hashtable__24HashEntry$object;

// Typedefs
typedef struct _jc_java_util_Hashtable__24Enumerator$sub_refs	_jc_java_util_Hashtable__24Enumerator$sub_refs;
typedef struct _jc_java_util_Hashtable__24Enumerator$sub_nonrefs	_jc_java_util_Hashtable__24Enumerator$sub_nonrefs;
typedef struct _jc_java_util_Hashtable__24Enumerator$refs	_jc_java_util_Hashtable__24Enumerator$refs;
typedef struct _jc_java_util_Hashtable__24Enumerator$nonrefs	_jc_java_util_Hashtable__24Enumerator$nonrefs;
typedef struct _jc_java_util_Hashtable__24Enumerator$object	_jc_java_util_Hashtable__24Enumerator$object;

typedef const struct _jc_java_util_Hashtable__24Enumerator$vmethods	_jc_java_util_Hashtable__24Enumerator$vmethods;
typedef const struct _jc_java_util_Hashtable__24Enumerator$vtable	_jc_java_util_Hashtable__24Enumerator$vtable;
typedef const struct _jc_java_util_Hashtable__24Enumerator$vtype	_jc_java_util_Hashtable__24Enumerator$vtype;

// Constructors
extern void _jc_java_util_Hashtable__24Enumerator$method$_init$cea83e7eef93edc7(_jc_env *, struct _jc_java_util_Hashtable__24Enumerator$object *, struct _jc_java_util_Hashtable$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_util_Hashtable__24Enumerator$method$hasMoreElements$95fbe58f36adadb0(_jc_env *, struct _jc_java_util_Hashtable__24Enumerator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_Hashtable__24Enumerator$method$nextElement$9b7c3789fa3ba818(_jc_env *, struct _jc_java_util_Hashtable__24Enumerator$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_Hashtable__24Enumerator$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_util_Hashtable__24Enumerator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_Hashtable__24Enumerator$method_info$hasMoreElements$95fbe58f36adadb0;
extern _jc_method _jc_java_util_Hashtable__24Enumerator$method_info$nextElement$9b7c3789fa3ba818;
extern _jc_method _jc_java_util_Hashtable__24Enumerator$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_util_Hashtable__24Enumerator$vmethods {
	jboolean	(*hasMoreElements$95fbe58f36adadb0)(_jc_env *, struct _jc_java_util_Hashtable__24Enumerator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*nextElement$9b7c3789fa3ba818)(_jc_env *, struct _jc_java_util_Hashtable__24Enumerator$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_util_Hashtable__24Enumerator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_Hashtable__24Enumerator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Hashtable__24Enumerator$vmethods	java_util_Hashtable__24Enumerator;
};

// Vtype
struct _jc_java_util_Hashtable__24Enumerator$vtype {
	_jc_type			type;
	_jc_java_util_Hashtable__24Enumerator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Hashtable__24Enumerator$sub_refs {
	struct _jc_java_util_Hashtable__24HashEntry$object	*next;
	struct _jc_java_util_Hashtable$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_Hashtable__24Enumerator$refs {
    _jc_java_util_Hashtable__24Enumerator$sub_refs	java_util_Hashtable__24Enumerator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Hashtable__24Enumerator$sub_nonrefs {
	jint	type;
	jint	count;
	jint	idx;
};

// Non-reference instance fields (object)
struct _jc_java_util_Hashtable__24Enumerator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Hashtable__24Enumerator$sub_nonrefs	java_util_Hashtable__24Enumerator;
};

// Object instance structure
struct _jc_java_util_Hashtable__24Enumerator$object {
	_jc_java_util_Hashtable__24Enumerator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Hashtable__24Enumerator$vtype	*vtype;
	_jc_java_util_Hashtable__24Enumerator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Hashtable__24Enumerator$vtype _jc_java_util_Hashtable__24Enumerator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Hashtable__24Enumerator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Hashtable__24Enumerator$class_object;

#endif	/* _JC_java_util_Hashtable__24Enumerator_H_ */
